@@ -35,8 +35,7 @@ class PurchaseRequest(ModelSQL, ModelView):
             'company': Eval('company', -1),
             },
         depends=['company'])
-    description = fields.Text('Description', readonly=True,
-        states=STATES, depends=DEPENDS)
+    description = fields.Text('Description', readonly=True)
     summary = fields.Function(fields.Char('Summary'), 'on_change_with_summary')
     party = fields.Many2One(
         'party.party', "Party", select=True, states=STATES,
